
__version__ = '0.1.5'  # METADATA_RESET:__version__ = '<<version>>'

"""
The ``_version.py`` file can be executed with execfile to create a local variable __version__::

    execfile('_version.py')             # python 2.x
    exec(open('_version.py').read())    # python 3.x

creates local __version__ variable.  

Used to set version info throughout the project.

------
"""



from engcoolprop.ec_fluid import EC_Fluid

# Print state point
ec = EC_Fluid(symbol="N2", T=530.0,P=100.0 ) # T=degR, P=psia
ec.setProps(T=500., D=0.1)

ec.printProps() # Print state point at given T,P




from engcoolprop.ec_fluid import EC_Fluid

# Print state point ( using 298.15K and 1 bar )
ec = EC_Fluid(symbol="ParaHydrogen", T=298.15*1.8,P=14.5038 ) # T=degR, P=psia

ec.printProps() # Print state point at given T,P

